module Aws.Lambda
  ( module Reexported
  ) where

import Aws.Lambda.Configuration as Reexported
import Aws.Lambda.Runtime as Reexported
import Aws.Lambda.Runtime.Context as Reexported
import Aws.Lambda.Runtime.ApiGatewayInfo as Reexported
